==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QTextBlock_iterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextBlock>
#include <QtCore/QVariant>
#include <QtGui/qtextobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextBlock_iterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextBlock::iterator")
    QTextBlock::iterator *_ptr = reinterpret_cast<QTextBlock::iterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new iterator()
void __qt_construct_QTextBlock_iterator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator()")
    Q_UNUSED(__java_arguments)
    QTextBlock::iterator *__qt_this = new(__qtjambi_ptr) QTextBlock::iterator();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTextBlock::iterator
void __qt_destruct_QTextBlock_iterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextBlock::iterator")
    reinterpret_cast<QTextBlock::iterator*>(ptr)->~iterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextBlock::iterator::iterator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_initialize_1native__Lio_qt_gui_QTextBlock_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextBlock::iterator::iterator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextBlock_iterator_0, sizeof(QTextBlock::iterator), typeid(QTextBlock::iterator), false, &deleter_QTextBlock_iterator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextBlock::iterator::atEnd()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_atEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::atEnd()const", __qt_this)
        __java_return_value = __qt_this->atEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextBlock::iterator::fragment()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_fragment_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::fragment()const", __qt_this)
        QTextFragment __qt_return_value = __qt_this->fragment();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextBlock::iterator::operator++()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator++()", __qt_this)
        QTextBlock::iterator& __qt_return_value = ++(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextBlock::iterator::operator--()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_previous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator--()", __qt_this)
        QTextBlock::iterator& __qt_return_value = --(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextBlock::iterator::operator==(QTextBlock::iterator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_equals_1native_1cref_1QTextBlock_1iterator_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID o0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator==(QTextBlock::iterator)const", __qt_this)
        const QTextBlock::iterator& __qt_o0 = QtJambiAPI::valueReferenceFromNativeId<QTextBlock::iterator>(o0);
        __java_return_value = (*__qt_this) == __qt_o0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextBlock_iterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextBlock::iterator>("QTextBlock::iterator", "io/qt/gui/QTextBlock$iterator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextBlock_iterator, {
        ConstructorInfo(&__qt_construct_QTextBlock_iterator_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextBlock_iterator);
    registerMetaType<QTextBlock::iterator>("QTextBlock::iterator");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QTextBlock_iterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextBlock>
#include <QtCore/QVariant>
#include <QtGui/qtextobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextBlock_iterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextBlock::iterator")
    QTextBlock::iterator *_ptr = reinterpret_cast<QTextBlock::iterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new iterator()
void __qt_construct_QTextBlock_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator()")
    Q_UNUSED(__java_arguments)
    QTextBlock::iterator *__qt_this = new(__qtjambi_ptr) QTextBlock::iterator();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextBlock::iterator::iterator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_initialize_1native__Lio_qt_gui_QTextBlock_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextBlock::iterator::iterator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextBlock_iterator, sizeof(QTextBlock::iterator), typeid(QTextBlock::iterator), false, &deleter_QTextBlock_iterator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new iterator(QTextBlock::iterator)
void __qt_construct_QTextBlock_iterator_cref_QTextBlock_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator(QTextBlock::iterator)")
    jobject other0 = __java_arguments[0].l;
    const QTextBlock::iterator& __qt_other0 = qtjambi_cast<const QTextBlock::iterator& >(__jni_env, other0);
    QTextBlock::iterator *__qt_this = new(__qtjambi_ptr) QTextBlock::iterator(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextBlock::iterator::iterator(QTextBlock::iterator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_initialize_1native__Lio_qt_gui_QTextBlock_00024iterator_2Lio_qt_gui_QTextBlock_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextBlock::iterator::iterator(QTextBlock::iterator)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextBlock_iterator_cref_QTextBlock_iterator, sizeof(QTextBlock::iterator), typeid(QTextBlock::iterator), false, &deleter_QTextBlock_iterator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextBlock::iterator
void __qt_destruct_QTextBlock_iterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextBlock::iterator")
    reinterpret_cast<QTextBlock::iterator*>(ptr)->~iterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextBlock::iterator::atEnd()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_atEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::atEnd()const", __qt_this)
        __java_return_value = __qt_this->atEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextBlock::iterator::fragment()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_fragment_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::fragment()const", __qt_this)
        QTextFragment __qt_return_value = __qt_this->fragment();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextBlock::iterator::operator++()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator++()", __qt_this)
        QTextBlock::iterator& __qt_return_value = ++(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextBlock::iterator::operator--()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_previous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator--()", __qt_this)
        QTextBlock::iterator& __qt_return_value = --(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextBlock::iterator::operator==(QTextBlock::iterator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_equals_1native_1cref_1QTextBlock_1iterator_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID o0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextBlock::iterator::operator==(QTextBlock::iterator)const", __qt_this)
        const QTextBlock::iterator& __qt_o0 = QtJambiAPI::valueReferenceFromNativeId<QTextBlock::iterator>(o0);
        __java_return_value = (*__qt_this) == __qt_o0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlock_00024iterator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextBlock::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextBlock::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextBlock_iterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextBlock::iterator>("QTextBlock::iterator", "io/qt/gui/QTextBlock$iterator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextBlock_iterator, {
        ConstructorInfo(&__qt_construct_QTextBlock_iterator, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextBlock_iterator_cref_QTextBlock_iterator, "Lio/qt/gui/QTextBlock$iterator;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextBlock_iterator);
    registerMetaType<QTextBlock::iterator>("QTextBlock::iterator");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
